lookForVarsAbsentInForest: Look for Variable ID's that didn't occur in the Forest.
Description
Find any remaining vars, if missing. Vars can be absent in the forest, if
they were never used to split. This function does some bookkeeping, to find
elements in the count vector that should be 0. If there weren't enough vars
observed, their indeces must be either at the end of vars_used, or the
beginning.